Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(65)

Unified Diff: runtime/vm/object.cc

Issue 1138993005: Revert 45783 (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/object.h ('k') | runtime/vm/object_store.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.cc
diff --git a/runtime/vm/object.cc b/runtime/vm/object.cc
index 3f58608ed75d1fd648ef230a672fd8b729a2f603..a7eaa7b3cdf304478217e5142d3ed1f068589884 100644
--- a/runtime/vm/object.cc
+++ b/runtime/vm/object.cc
@@ -1211,19 +1211,19 @@ RawError* Object::Init(Isolate* isolate) {
RegisterPrivateClass(cls, Symbols::_LinkedHashMap(), lib);
pending_classes.Add(cls);
// Pre-register the developer library so we can place the vm class
// UserTag there rather than the core library.
- lib = Library::LookupLibrary(Symbols::DartDeveloper());
+ lib = Library::LookupLibrary(Symbols::DartProfiler());
if (lib.IsNull()) {
- lib = Library::NewLibraryHelper(Symbols::DartDeveloper(), true);
+ lib = Library::NewLibraryHelper(Symbols::DartProfiler(), true);
lib.SetLoadRequested();
lib.Register();
- object_store->set_bootstrap_library(ObjectStore::kDeveloper, lib);
+ object_store->set_bootstrap_library(ObjectStore::kProfiler, lib);
}
ASSERT(!lib.IsNull());
- ASSERT(lib.raw() == Library::DeveloperLibrary());
+ ASSERT(lib.raw() == Library::ProfilerLibrary());
- lib = Library::LookupLibrary(Symbols::DartDeveloper());
+ lib = Library::LookupLibrary(Symbols::DartProfiler());
ASSERT(!lib.IsNull());
cls = Class::New<UserTag>();
RegisterPrivateClass(cls, Symbols::_UserTag(), lib);
@@ -9863,6 +9863,11 @@ RawLibrary* Library::NativeWrappersLibrary() {
}
+RawLibrary* Library::ProfilerLibrary() {
+ return Isolate::Current()->object_store()->profiler_library();
+}
+
+
RawLibrary* Library::TypedDataLibrary() {
return Isolate::Current()->object_store()->typed_data_library();
}
@@ -10476,14 +10481,14 @@ void Library::CheckFunctionFingerprints() {
POLYMORPHIC_TARGET_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
- all_libs.Add(&Library::ZoneHandle(Library::DeveloperLibrary()));
- DEVELOPER_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
-
- all_libs.Clear();
all_libs.Add(&Library::ZoneHandle(Library::MathLibrary()));
MATH_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
+ all_libs.Add(&Library::ZoneHandle(Library::ProfilerLibrary()));
+ PROFILER_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
+
+ all_libs.Clear();
all_libs.Add(&Library::ZoneHandle(Library::TypedDataLibrary()));
TYPED_DATA_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
« no previous file with comments | « runtime/vm/object.h ('k') | runtime/vm/object_store.h » ('j') | no next file with comments »
@@ -1211,19 +1211,19 @@ RawError* Object::Init(Isolate* isolate) {
RegisterPrivateClass(cls, Symbols::_LinkedHashMap(), lib);
pending_classes.Add(cls);
- // Pre-register the developer library so we can place the vm class
+ // Pre-register the profiler library so we can place the vm class
// UserTag there rather than the core library.

Powered by Google App Engine
This is Rietveld 408576698